@@ -84,9 +84,24 @@ struct FMIconViewClass {
 	 */
 	gboolean (* supports_auto_layout)	 (FMIconView *view);
 
+	/* supports_auto_layout is a function pointer that subclasses may
+	 * override to control whether snap-to-grid mode
+	 * should be enabled. The default implementation returns FALSE.
+	 */
+	gboolean (* supports_keep_aligned)	 (FMIconView *view);
+
+	/* supports_auto_layout is a function pointer that subclasses may
+	 * override to control whether snap-to-grid mode
+	 * should be enabled. The default implementation returns FALSE.
+	 */
+	gboolean (* supports_labels_beside_icons)	 (FMIconView *view);
 };
 
-/* GtkObject support */
-GtkType fm_icon_view_get_type (void);
+/* GObject support */
+GType   fm_icon_view_get_type      (void);
+int     fm_icon_view_compare_files (FMIconView   *icon_view,
+				    NautilusFile *a,
+				    NautilusFile *b);
+void    fm_icon_view_filter_by_screen (FMIconView *icon_view, gboolean filter);
 
 #endif /* FM_ICON_VIEW_H */
