@@ -29,6 +29,7 @@
  */
 
 #include <config.h>
+#include <math.h>
 #include "nautilus-property-browser.h"
 
 #include "nautilus-signaller.h"
@@ -66,12 +67,12 @@
 #include <gtk/gtkradiobutton.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkviewport.h>
-#include <libegg/egg-screen-help.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-help.h>
 #include <libgnomeui/gnome-color-picker.h>
 #include <libgnomeui/gnome-icon-entry.h>
+#include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -85,7 +86,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-theme.h>
-#include <math.h>
 #include <atk/atkrelationset.h>
 
 /* property types */
@@ -210,7 +210,7 @@ static void     element_clicked_callback                        (GtkWidget
 #define ERASE_OBJECT_NAME "erase.png"
 
 enum {
-	PROPERTY_TYPE,
+	PROPERTY_TYPE
 };
 
 static GtkTargetEntry drag_types[] = {
@@ -678,7 +678,8 @@ ensure_uri_is_image (const char *uri)
 		 GNOME_VFS_FILE_INFO_GET_MIME_TYPE
 		 | GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
         is_image = eel_istr_has_prefix (file_info->mime_type, "image/")
-		&& eel_strcasecmp (file_info->mime_type, "image/svg") != 0;
+		&& eel_strcasecmp (file_info->mime_type, "image/svg") != 0
+		&& eel_strcasecmp (file_info->mime_type, "image/svg+xml") != 0;
 	gnome_vfs_file_info_unref (file_info);
 	return is_image;
 }
@@ -694,11 +695,17 @@ make_drag_image (NautilusPropertyBrowser *property_browser, const char* file_nam
 	gboolean is_reset;
 
 	if (property_browser->details->category_type == NAUTILUS_PROPERTY_EMBLEM) {
-		icon_name = nautilus_emblem_get_icon_name_from_keyword (file_name);
-		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL,
-								     NAUTILUS_ICON_SIZE_STANDARD,
-								     NULL);
-		g_free (icon_name);
+		if (strcmp (file_name, "erase") == 0) {
+			image_file_name = nautilus_pixmap_file (ERASE_OBJECT_NAME);
+			pixbuf = gdk_pixbuf_new_from_file (image_file_name, NULL);
+			g_free (image_file_name);
+		} else {
+			icon_name = nautilus_emblem_get_icon_name_from_keyword (file_name);
+			pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL,
+									     NAUTILUS_ICON_SIZE_STANDARD,
+									     NULL);
+			g_free (icon_name);
+		}
 		return pixbuf;
 	}
 
@@ -905,7 +912,8 @@ remove_pattern(NautilusPropertyBrowser *property_browser, const char* pattern_na
 	/* delete the pattern from the pattern directory */
 	if (gnome_vfs_unlink (pattern_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but pattern %s couldn't be deleted."), pattern_name);
-		eel_show_error_dialog (message, _("Couldn't delete pattern"), GTK_WINDOW (property_browser));
+		char *detail = _("Check that you have permission to delete the pattern.");
+		eel_show_error_dialog (message, detail, _("Couldn't Delete Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	
@@ -934,7 +942,8 @@ remove_emblem (NautilusPropertyBrowser *property_browser, const char* emblem_nam
 	/* delete the emblem from the emblem directory */
 	if (gnome_vfs_unlink (emblem_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but emblem %s couldn't be deleted."), emblem_name);
-		eel_show_error_dialog (message, _("Couldn't delete pattern"), GTK_WINDOW (property_browser));
+		char *detail = _("Check that you have permission to delete the emblem.");
+		eel_show_error_dialog (message, detail, _("Couldn't Delete Emblem"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	else {
@@ -1091,12 +1100,15 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	/* make sure that it's a valid path */
 	if (path_name == NULL || path_name[0] != '/') {
 		char *message;
+		char *detail;
 		if (path_name != NULL) {
 			message = g_strdup_printf (_("Sorry, but \"%s\" is not a valid file name."), path_name);
+			detail = _("Please check the spelling and try again.");
 		} else {
 			message = g_strdup (_("Sorry, but you did not supply a valid file name."));
+			detail = _("Please try again.");
 		}
-		eel_show_error_dialog (message, _("Couldn't install pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, detail, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 		return;
 	}
@@ -1107,7 +1119,9 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	/* don't allow the user to change the reset image */
 	basename = eel_uri_get_basename (path_uri);
 	if (basename && eel_strcmp (basename, RESET_IMAGE_NAME) == 0) {
-		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), _("Not an Image"), NULL);
+		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), 
+		                       _("Reset is a special image that cannot be deleted."), 
+		                       _("Not an Image"), NULL);
 		g_free (path_uri);
 		g_free (basename);
 		return;
@@ -1139,7 +1153,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	result = eel_copy_uri_simple (path_name, destination_name);		
 	if (result != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but the pattern %s couldn't be installed."), path_name);
-		eel_show_error_dialog (message, _("Couldn't install pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, NULL, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 		
@@ -1219,8 +1233,9 @@ add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 		color_name = gtk_entry_get_text (GTK_ENTRY (property_browser->details->color_name));
 		stripped_color_name = g_strstrip (g_strdup (color_name));
 		if (strlen (stripped_color_name) == 0) {
-			eel_show_error_dialog (_("Sorry, but you must specify a non-blank name for the new color."), 
-						    _("Couldn't install color"), GTK_WINDOW (property_browser));
+			eel_show_error_dialog (_("The color cannot be installed."),
+					       _("Sorry, but you must specify a non-blank name for the new color."), 
+			                       _("Couldn't Install Color"), GTK_WINDOW (property_browser));
 		
 		} else {
 			add_color_to_file (property_browser, color_spec, stripped_color_name);
@@ -1309,8 +1324,8 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 					property_browser->details->image_path = emblem_path;				
 				} else {
 					char *message = g_strdup_printf
-						(_("Sorry, but '%s' is not a usable image file!"), emblem_path);
-					eel_show_error_dialog (message, _("Not an Image"), GTK_WINDOW (property_browser));
+						(_("Sorry, but \"%s\" is not a usable image file."), emblem_path);
+					eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
 					g_free (message);
 					g_free (emblem_path);
 					return;
@@ -1325,8 +1340,9 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 
 		if (pixbuf == NULL) {
 			char *message = g_strdup_printf
-				(_("Sorry, but '%s' is not a usable image file!"), property_browser->details->image_path);
-			eel_show_error_dialog (message, _("Not an Image"), GTK_WINDOW (property_browser));
+				(_("Sorry, but \"%s\" is not a usable image file."), property_browser->details->image_path);
+			eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
+			g_free (message);
 		}
 		
 		new_keyword = gtk_entry_get_text(GTK_ENTRY(property_browser->details->keyword));		
@@ -1341,6 +1357,8 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 						       stripped_keyword,
 						       stripped_keyword,
 						       GTK_WINDOW (property_browser));
+
+		nautilus_emblem_refresh_list ();
 		
 		emit_emblems_changed_signal ();	
 		nautilus_property_browser_update_contents (property_browser);
@@ -1426,15 +1444,15 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
 	GError *error = NULL;
 	GtkWidget *dialog;
 
-	egg_help_display_desktop_on_screen (
-		NULL, "user-guide", "wgosnautilus.xml", "gosnautilus-50",
+	gnome_help_display_desktop_on_screen (
+		NULL, "user-guide", "user-guide.xml", "gosnautilus-50",
 		gtk_window_get_screen (GTK_WINDOW (property_browser)), &error);
 
 	if (error) {
 		dialog = gtk_message_dialog_new (GTK_WINDOW (property_browser),
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
+						 GTK_BUTTONS_OK,
 						 _("There was an error displaying help: \n%s"),
 						 error->message);
 
@@ -1606,12 +1624,14 @@ make_properties_from_directories (NautilusPropertyBrowser *property_browser)
 	GdkPixbuf *object_pixbuf;
 	EelImageTable *image_table;
 	GtkWidget *reset_object = NULL;
-	GtkWidget *erase_object = NULL;
 	GList *icons, *l;
 	char *icon_name;
 	char *keyword;
 	char *extension;
 	GtkWidget *property_image;
+	GtkWidget *blank;
+	guint num_images;
+	char *path;
 
 	g_return_if_fail (NAUTILUS_IS_PROPERTY_BROWSER (property_browser));
 	g_return_if_fail (EEL_IS_IMAGE_TABLE (property_browser->details->content_table));
@@ -1653,15 +1673,6 @@ make_properties_from_directories (NautilusPropertyBrowser *property_browser)
 
 			gtk_container_add (GTK_CONTAINER (image_table), property_image);
 			gtk_widget_show (property_image);
-
-			/* Keep track of ERASE objects to place them prominently later */
-			if (eel_str_is_equal (object_name, ERASE_OBJECT_NAME)) {
-				g_assert (erase_object == NULL);
-				erase_object = property_image;
-				/* Keep track of RESET objects to place them prominently later */
-			}
-			
-			gtk_widget_show (property_image);
 					
 			g_free (object_name);
 			g_free (object_label);
@@ -1711,25 +1722,30 @@ make_properties_from_directories (NautilusPropertyBrowser *property_browser)
 	/*
 	 * We place ERASE objects (for emblems) at the end with a blank in between.
 	 */
-	if (erase_object != NULL) {
-		GtkWidget *blank;
-		guint num_images;
-
-		g_assert (EEL_IS_LABELED_IMAGE (erase_object));
-
+	if (property_browser->details->category_type == NAUTILUS_PROPERTY_EMBLEM) {
 		blank = eel_image_table_add_empty_image (image_table);
 		labeled_image_configure (EEL_LABELED_IMAGE (blank));
+	
 		
 		num_images = eel_wrap_table_get_num_children (EEL_WRAP_TABLE (image_table));
 		g_assert (num_images > 0);
 		eel_wrap_table_reorder_child (EEL_WRAP_TABLE (image_table),
-						   blank,
-						   num_images - 1);
+					      blank,
+					      num_images - 1);
 		
 		gtk_widget_show (blank);
+		
+		path = nautilus_pixmap_file (ERASE_OBJECT_NAME);
+		object_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+		g_free (path);
+		property_image = labeled_image_new (_("Erase"), object_pixbuf, "erase", PANGO_SCALE_LARGE);
+		eel_labeled_image_set_fixed_image_height (EEL_LABELED_IMAGE (property_image), MAX_EMBLEM_HEIGHT);
+
+		gtk_container_add (GTK_CONTAINER (image_table), property_image);
+		gtk_widget_show (property_image);
+	
 		eel_wrap_table_reorder_child (EEL_WRAP_TABLE (image_table),
-						   erase_object,
-						   -1);
+					      property_image, -1);
 	}
 
 	/*
@@ -2032,7 +2048,7 @@ nautilus_property_browser_update_contents (NautilusPropertyBrowser *property_bro
 	/* update the title and button */
 
 	if (property_browser->details->category == NULL) {
-		gtk_label_set_text (GTK_LABEL (property_browser->details->title_label), _("Select A Category:"));
+		gtk_label_set_text (GTK_LABEL (property_browser->details->title_label), _("Select a Category:"));
 		gtk_widget_hide(property_browser->details->add_button);
 		gtk_widget_hide(property_browser->details->remove_button);
 	
